"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateMaxFileSize = exports.setDefinedGlobals = exports.setExternalLibrary = void 0;
const lexisGlobals_1 = require("./lexisGlobals");
const path = require("path");
function setExternalLibrary(config, context, folder, enable) {
    console.log("setExternalLibrary", folder, enable);
    const extensionId = context.extension.id;
    const extensionPath = context.extension.extensionPath;
    const folderPath = extensionPath ? path.join(extensionPath, folder) : "";
    if (extensionPath) {
        const configKey = "workspace.library";
        config[configKey] = config[configKey] || [];
        const library = config[configKey];
        // remove any older versions of our path e.g. "publisher.name-0.0.1"
        for (let i = library.length - 1; i >= 0; i--) {
            const el = library[i];
            const isSelfExtension = el.toLowerCase().indexOf(extensionId.toLowerCase()) > -1;
            const isCurrentVersion = el.toLowerCase().indexOf(extensionPath.toLowerCase()) > -1;
            if (isSelfExtension && !isCurrentVersion) {
                library.splice(i, 1);
            }
        }
        const index = library.indexOf(folderPath);
        if (enable) {
            if (index === -1) {
                library.push(folderPath);
            }
        }
        else {
            if (index > -1) {
                library.splice(index, 1);
            }
        }
    }
}
exports.setExternalLibrary = setExternalLibrary;
function setDefinedGlobals(config, enable) {
    console.log('setting globals');
    const configKey = "diagnostics.globals";
    config[configKey] = config[configKey] || [];
    const definedGlobals = config[configKey];
    const globals = lexisGlobals_1.LEXIS_GLOBALS;
    globals.forEach(global => {
        const index = definedGlobals.indexOf(global);
        if (index === -1 && enable) {
            definedGlobals.push(global);
            console.log(`added ${global} to globals`);
        }
        else if (index !== -1 && !enable) {
            definedGlobals.splice(index, 1);
            console.log(`removed ${global} from globals`);
        }
    });
}
exports.setDefinedGlobals = setDefinedGlobals;
function updateMaxFileSize(config) {
    const ourfilesize = 120;
    const currentSize = config["workspace.preloadFileSize"] || 150;
    if (currentSize < ourfilesize) {
        // increase preloadFileSize to make sure our config gets loaded
        console.log(`Bumping Lua preloadFileSize to ${ourfilesize}`);
        config["workspace.preloadFileSize"] = ourfilesize;
    }
}
exports.updateMaxFileSize = updateMaxFileSize;
//# sourceMappingURL=luaSettings.js.map